@@ -27,10 +27,8 @@ def is_name_valid(app_name):
 #get all arguments passed
 def get_args():
   args = sys.argv
-  print(args)
-  args.pop(0)
-  args.pop(1)
-  print(args)
+  print(args.index(0))
+  print(args.index(1))
   return args
 
 def is_args_valid(args):
